@@ -3,24 +3,17 @@ from argparse import REMAINDER, ArgumentParser
 from typing import List
 
 # app
-from ..actions import attach_deps, get_resolver, make_json
+from ..actions import get_resolver, make_json
 from ..config import builders
-from ..controllers import analyze_conflict
-from ..converters import CONVERTERS
 from .base import BaseCommand
 
 
 class DepsTreeCommand(BaseCommand):
     """Show dependencies tree.
-
-    https://dephell.readthedocs.io/en/latest/cmd-deps-tree.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell deps tree',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_from(parser)
         builders.build_resolver(parser)
@@ -35,24 +28,11 @@ class DepsTreeCommand(BaseCommand):
     def __call__(self) -> bool:
         if self.args.name:
             resolver = get_resolver(reqs=self.args.name)
+            resolver = self._resolve(resolver=resolver)
         else:
-            loader = CONVERTERS[self.config['from']['format']]
-            resolver = loader.load_resolver(path=self.config['from']['path'])
-            attach_deps(resolver=resolver, config=self.config, merge=False)
-
-        # resolve
-        self.logger.debug('resolving...')
-        resolved = resolver.resolve(silent=self.config['silent'])
-        if not resolved:
-            conflict = analyze_conflict(resolver=resolver)
-            self.logger.warning('conflict was found')
-            print(conflict)
+            resolver = self._get_locked()
+        if resolver is None:
             return False
-        self.logger.debug('resolved')
-
-        # apply envs if needed
-        if 'envs' in self.config:
-            resolver.apply_envs(set(self.config['envs']))
 
         if self.args.type == 'pretty':
             for dep in sorted(resolver.graph.get_layer(1)):
