@@ -5,8 +5,8 @@ from getpass import getuser
 from pathlib import Path
 
 # external
-from dephell_licenses import licenses
 from dephell_discover import Root as PackageRoot
+from dephell_licenses import licenses
 
 # app
 from ..config import builders
@@ -16,15 +16,10 @@ from .base import BaseCommand
 
 class GenerateLicenseCommand(BaseCommand):
     """Create LICENSE file.
-
-    https://dephell.readthedocs.io/en/latest/cmd-generate-license.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell generate license',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_other(parser)
@@ -50,6 +45,7 @@ class GenerateLicenseCommand(BaseCommand):
         # get author from `from`
         if not author and 'from' in self.config:
             loader = CONVERTERS[self.config['from']['format']]
+            loader = loader.copy(project_path=Path(self.config['project']))
             root = loader.load(self.config['from']['path'])
             if root.authors:
                 author = root.authors[0]
