@@ -14,15 +14,10 @@ from .base import BaseCommand
 
 class InspectSelfCommand(BaseCommand):
     """Show information about DepHell installation.
-
-    https://dephell.readthedocs.io/en/latest/cmd-inspect-self.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell inspect self',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_other(parser)
