@@ -12,15 +12,10 @@ from .base import BaseCommand
 
 class InspectVenvCommand(BaseCommand):
     """Show virtual environment information for current project.
-
-    https://dephell.readthedocs.io/en/latest/cmd-inspect-venv.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell inspect venv',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_venv(parser)
         builders.build_output(parser)
