@@ -18,15 +18,10 @@ from .base import BaseCommand
 
 class JailInstallCommand(BaseCommand):
     """Download and install package into isolated environment.
-
-    https://dephell.readthedocs.io/en/latest/cmd-jail-install.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell jail install',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_venv(parser)
         builders.build_resolver(parser)
