@@ -10,15 +10,10 @@ from .base import BaseCommand
 
 class PackageShowCommand(BaseCommand):
     """Show information about package from PyPI.org.
-
-    https://dephell.readthedocs.io/en/latest/cmd-package-show.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell package show',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_venv(parser)
         builders.build_output(parser)
