@@ -13,15 +13,10 @@ from .base import BaseCommand
 
 class VenvCreateCommand(BaseCommand):
     """Create virtual environment for current project.
-
-    https://dephell.readthedocs.io/en/latest/cmd-venv-create.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell venv create',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_from(parser)
         builders.build_venv(parser)
