@@ -1,5 +1,9 @@
+# project
+# external
+from dephell_versioning import get_schemes
+
 # app
-from ..constants import FORMATS, LOG_FORMATTERS, LOG_LEVELS, REPOSITORIES, STRATEGIES, VERSION_SCHEMES
+from ..constants import FORMATS, LOG_FORMATTERS, LOG_LEVELS, REPOSITORIES, STRATEGIES
 
 
 env_help = (
@@ -68,6 +72,13 @@ def build_venv(parser):
     venv_group.add_argument('--dotenv', help='path to .env file')
 
 
+def build_docker(parser):
+    venv_group = parser.add_argument_group('Docker container')
+    venv_group.add_argument('--docker-repo', help='image name without tag')
+    venv_group.add_argument('--docker-tag', help='image tag')
+    venv_group.add_argument('--docker-container', help='container name')
+
+
 def build_other(parser):
     other_group = parser.add_argument_group('Other')
 
@@ -79,4 +90,5 @@ def build_other(parser):
 
     other_group.add_argument('--envs', nargs='*', help='environments (main, dev) or extras to install')
     other_group.add_argument('--tests', nargs='*', help='paths to test files')
-    other_group.add_argument('--versioning', choices=sorted(VERSION_SCHEMES), help='versioning scheme for project')
+    other_group.add_argument('--versioning', choices=sorted(get_schemes()),
+                             help='versioning scheme for project')
