@@ -1,11 +1,12 @@
 # app
 from ._conflict import analyze_conflict
 from ._dependency import DependencyMaker
+from ._docker import DockerContainer, DockerContainers
 from ._graph import Graph
 from ._mutator import Mutator
 from ._readme import Readme
-from ._resolver import Resolver
 from ._repos import RepositoriesRegistry
+from ._resolver import Resolver
 from ._safety import Safety, SafetyVulnInfo
 from ._snyk import Snyk, SnykVulnInfo
 
@@ -13,6 +14,8 @@ from ._snyk import Snyk, SnykVulnInfo
 __all__ = [
     'analyze_conflict',
     'DependencyMaker',
+    'DockerContainer',
+    'DockerContainers',
     'Graph',
     'Mutator',
     'Readme',
