@@ -5,12 +5,14 @@ from types import SimpleNamespace
 from typing import Optional
 
 # external
+from dephell_discover import Root as PackageRoot
 from dephell_links import DirLink
 from pip._internal.download import PipSession
 from pip._internal.index import PackageFinder
 from pip._internal.req import parse_requirements
 
 # app
+from ..context_tools import chdir
 from ..controllers import DependencyMaker, RepositoriesRegistry
 from ..models import RootDependency
 from ..repositories import WarehouseBaseRepo, WarehouseLocalRepo
@@ -36,40 +38,42 @@ class PIPConverter(BaseConverter):
         else:
             return (path.name == 'requirements.in')
 
-    def __init__(self, lock):
-        self.lock = lock
-
     def load(self, path) -> RootDependency:
-        deps = []
-        root = RootDependency()
+        if isinstance(path, str):
+            path = Path(path)
+        path = self._make_source_path_absolute(path)
+        self._resolve_path = path.parent
 
-        finder = PackageFinder(
-            find_links=[],
-            index_urls=[],
-            session=PipSession(),
+        root = RootDependency(
+            package=PackageRoot(path=self.project_path or path.parent),
         )
+
+        finder = self._get_finder()
+
         # https://github.com/pypa/pip/blob/master/src/pip/_internal/req/constructors.py
-        reqs = parse_requirements(
-            filename=str(path),
-            session=PipSession(),
-            finder=finder,
-        )
+        with chdir(self.resolve_path or path.parent):
+            reqs = parse_requirements(
+                filename=str(path),
+                session=PipSession(),
+                finder=finder,
+            )
 
-        for req in reqs:
-            # https://github.com/pypa/pip/blob/master/src/pip/_internal/req/req_install.py
-            if req.req is None:
-                req.req = SimpleNamespace(
-                    name=req.link.url.split('/')[-1],
-                    specifier='*',
-                    marker=None,
-                    extras=None,
-                )
-            deps.extend(DependencyMaker.from_requirement(
-                source=root,
-                req=req.req,
-                url=req.link and req.link.url,
-                editable=req.editable,
-            ))
+            deps = []
+            for req in reqs:
+                # https://github.com/pypa/pip/blob/master/src/pip/_internal/req/req_install.py
+                if req.req is None:
+                    req.req = SimpleNamespace(
+                        name=req.link.url.split('/')[-1],
+                        specifier='*',
+                        marker=None,
+                        extras=None,
+                    )
+                deps.extend(DependencyMaker.from_requirement(
+                    source=root,
+                    req=req.req,
+                    url=req.link and req.link.url,
+                    editable=req.editable,
+                ))
 
         # update repository
         if finder.index_urls or finder.find_links:
@@ -121,6 +125,22 @@ class PIPConverter(BaseConverter):
             lines.append(self._format_req(req=req, with_hashes=with_hashes))
         return '\n'.join(lines) + '\n'
 
+    @staticmethod
+    def _get_finder():
+        try:
+            return PackageFinder(find_links=[], index_urls=[], session=PipSession())
+        except TypeError:
+            pass
+
+        from pip._internal.models.search_scope import SearchScope
+        from pip._internal.models.selection_prefs import SelectionPreferences
+
+        return PackageFinder.create(
+            search_scope=SearchScope(find_links=[], index_urls=[]),
+            selection_prefs=SelectionPreferences(allow_yanked=False),
+            session=PipSession(),
+        )
+
     # https://github.com/pypa/packaging/blob/master/packaging/requirements.py
     # https://github.com/jazzband/pip-tools/blob/master/piptools/utils.py
     def _format_req(self, req, *, with_hashes: bool = True) -> str:
@@ -128,8 +148,14 @@ class PIPConverter(BaseConverter):
         if req.editable:
             line += '-e '
         if req.link is not None:
-            req.link.name = req.name  # patch `#=egg` by right name
-            line += req.link.long
+            link = req.link.long
+            path = Path(link.split('#egg=')[0])
+            if path.exists():
+                link = str(self._make_dependency_path_relative(path))
+                link = link.replace('\\', '/')
+                if '/' not in link:
+                    link = './' + link
+            line += link
         else:
             line += req.raw_name
         if req.extras:
