@@ -5,12 +5,14 @@ from typing import List, Optional
 
 # external
 import tomlkit
+from dephell_discover import Root as PackageRoot
 from dephell_specifier import RangeSpecifier
+from packaging.utils import canonicalize_name
 
 # app
 from ..controllers import DependencyMaker, Readme, RepositoriesRegistry
 from ..models import Author, Constraint, Dependency, EntryPoint, RootDependency
-from ..repositories import get_repo, WarehouseBaseRepo, WarehouseLocalRepo
+from ..repositories import WarehouseLocalRepo
 from .base import BaseConverter
 
 
@@ -39,7 +41,9 @@ class PoetryConverter(BaseConverter):
         elif 'poetry' not in doc['tool']:
             doc['tool']['poetry'] = tomlkit.table()
         section = doc['tool']['poetry']
-        root = RootDependency()
+        root = RootDependency(
+            package=PackageRoot(path=self.project_path or Path()),
+        )
 
         # read metainfo
         if 'name' in section:
@@ -79,6 +83,13 @@ class PoetryConverter(BaseConverter):
                 root.entrypoints.append(EntryPoint(name=name, path=path, group=group_name))
         root.entrypoints = tuple(root.entrypoints)
 
+        # update repository
+        root.repo = RepositoriesRegistry()
+        if section.get('source'):
+            for source in section['source']:
+                root.repo.add_repo(url=source['url'], name=source['name'])
+        root.repo.attach_config()
+
         # get envs for deps
         envs = defaultdict(set)
         for extra, deps in section.get('extras', {}).items():
@@ -103,16 +114,6 @@ class PoetryConverter(BaseConverter):
                     envs=envs.get(name),
                 ))
 
-        # update repository
-        if section.get('source'):
-            repo = RepositoriesRegistry()
-            for source in section['source']:
-                repo.add_repo(url=source['url'], name=source['name'])
-            repo.attach_config()
-            for dep in deps:
-                if isinstance(dep.repo, WarehouseBaseRepo):
-                    dep.repo = repo
-
         root.attach_dependencies(deps)
         return root
 
@@ -159,24 +160,47 @@ class PoetryConverter(BaseConverter):
         self._add_entrypoints(section=section, entrypoints=project.entrypoints)
 
         # dependencies
+        names_mapping = dict()
         for section_name, is_dev in [('dependencies', False), ('dev-dependencies', True)]:
             if section_name not in section:
                 section[section_name] = tomlkit.table()
                 continue
-            # clean dependencies from old dependencies
+
+            # clean file from outdated dependencies
             names = {req.name for req in reqs if is_dev is req.is_dev} | {'python'}
             for name in dict(section[section_name]):
-                if name not in names:
+                normalized_name = canonicalize_name(name)
+                names_mapping[normalized_name] = name
+                if normalized_name not in names:
                     del section[section_name][name]
 
         # python version
-        section['dependencies']['python'] = str(project.python) or '*'
+        if section['dependencies'].get('python', '') != (project.python or '*'):
+            section['dependencies']['python'] = str(project.python) or '*'
 
         # write dependencies
         for section_name, is_dev in [('dependencies', False), ('dev-dependencies', True)]:
             for req in reqs:
-                if is_dev is req.is_dev:
-                    section[section_name][req.raw_name] = self._format_req(req=req)
+                if is_dev is not req.is_dev:
+                    continue
+                raw_name = names_mapping.get(req.name, req.raw_name)
+                old_spec = section[section_name].get(raw_name)
+
+                # do not overwrite dep if nothing is changed
+                if old_spec:
+                    old_dep = self._make_deps(
+                        root=RootDependency(),
+                        name=raw_name,
+                        content=old_spec,
+                        envs={'main'},
+                    )[0]
+                    if req.same_dep(old_dep):
+                        continue
+
+                # overwrite
+                section[section_name][raw_name] = self._format_req(req=req)
+
+            # remove empty section
             if not section[section_name].value:
                 del section[section_name]
 
@@ -205,7 +229,9 @@ class PoetryConverter(BaseConverter):
             # deop all old extras if there are no new extras
             del section['extras']
 
-        self._add_repositories(section=section, reqs=reqs)
+        if not project.dependencies:
+            project.attach_dependencies([req.dep for req in reqs])
+        self._add_repositories(section=section, root=project)
         return tomlkit.dumps(doc).rstrip() + '\n'
 
     @staticmethod
@@ -213,7 +239,7 @@ class PoetryConverter(BaseConverter):
         # drop old console_scripts
         if 'scripts' in section:
             scripts = {e.name for e in entrypoints if e.group == 'console_scripts'}
-            for script_name in section['scripts']:
+            for script_name in list(section['scripts']):
                 if script_name not in scripts:
                     del section['scripts'][script_name]
 
@@ -256,34 +282,28 @@ class PoetryConverter(BaseConverter):
             section['plugins'][entrypoint.group][entrypoint.name] = entrypoint.path
 
     @staticmethod
-    def _add_repositories(section, reqs):
+    def _add_repositories(section, root: RootDependency):
         # get repositories
         urls = dict()
-        for req in reqs:
-            if not isinstance(req.dep.repo, WarehouseBaseRepo):
+        for repo in root.warehouses:
+            if isinstance(repo, WarehouseLocalRepo):
                 continue
-            for repo in req.dep.repo.repos:
-                if repo.from_config:
-                    continue
-                if isinstance(repo, WarehouseLocalRepo):
-                    continue
-                urls[repo.name] = repo.pretty_url
+            urls[repo.name] = repo.pretty_url
 
         # remove or update old repositories
         added = []
+        sources = tomlkit.aot()
         if section.get('source'):
-            old = list(section['source'])
-            section['source'] = tomlkit.aot()
-            added = []
-            for source in old:
+            if hasattr(section, 'item'):
+                old_sources = section.item('source')
+            else:
+                old_sources = section['source']
+            for source in old_sources:
                 if source['name'] in urls:
                     if source['url'] != urls[source['name']]:
                         source['url'] = urls[source['name']]
-                    section['source'].append(source)
+                    sources.append(source)
                     added.append(source['name'])
-            sources = section['source']
-        else:
-            sources = tomlkit.aot()
 
         # add new repositories
         for name, url in sorted(urls.items()):
@@ -295,20 +315,25 @@ class PoetryConverter(BaseConverter):
 
         section['source'] = sources
 
+        # remove section if empty
+        if not section['source']:
+            del section['source']
+
     # https://github.com/sdispater/tomlkit/blob/master/pyproject.toml
-    @staticmethod
-    def _make_deps(root, name: str, content, envs: set) -> List[Dependency]:
+    def _make_deps(self, root, name: str, content, envs: set) -> List[Dependency]:
         if isinstance(content, str):
             deps = [Dependency(
                 raw_name=name,
                 constraint=Constraint(root, content),
-                repo=get_repo(),
+                repo=root.repo,
                 envs=envs,
             )]
             return deps
 
         # get link
         url = content.get('file') or content.get('path')
+        if url and not url.startswith('http'):
+            url = str(self._make_dependency_path_absolute(Path(url)))
         if not url and 'git' in content:
             url = 'git+' + content['git']
         rev = content.get('rev') or content.get('branch') or content.get('tag')
@@ -327,6 +352,7 @@ class PoetryConverter(BaseConverter):
         deps = DependencyMaker.from_params(
             raw_name=name,
             constraint=Constraint(root, content.get('version', '')),
+            source=root,
             extras=set(content.get('extras', [])),
             marker=markers or None,
             url=url,
@@ -345,7 +371,7 @@ class PoetryConverter(BaseConverter):
                 result[name] = value
         if req.prereleases:
             result['allows-prereleases'] = True
-        if 'version' not in result:
+        if 'version' not in result and 'git' not in result:
             result['version'] = '*'
         # if we have only version, return string instead of table
         if tuple(result.value) == ('version', ):
