@@ -1,7 +1,7 @@
 # built-in
 import abc
 import re
-from typing import Optional, Iterable, List, Dict
+from typing import Dict, Iterable, List, Optional
 
 
 REX_TOKEN = re.compile(r'^((?P<field>[a-z_]+)\:)?(?P<value>.+)$')
